@@ -17,10 +17,4 @@
 # specific language governing permissions and limitations
 # under the License.
 
-DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
-
-export AIRFLOW__CORE__DAGS_FOLDER="$DIR/tests/runners/airflow/liminal/"
-
 python -m unittest
-
-python check_license.py
